@@ -6,6 +6,7 @@ from collections import defaultdict
 from jieba import Tokenizer
 
 from hiword.dataloader import DictLoader, IDFLoader, StopwordsLoader
+from hiword.zh_hans import traditional_to_simple
 
 __all__ = ['KeywordsExtractor', 'extract_keywords']
 
@@ -88,9 +89,10 @@ class KeywordsExtractor:
             end_pos = len(continuous_words)
             if end_pos > 0:
                 for i in range(0, end_pos - 1):
-                    word = ''.join(continuous_words[i:end_pos])
-                    appears[word] += 1
-                    parts[word] = continuous_words[i:end_pos]
+                    for j in range(i + 2, end_pos + 1):
+                        word = ''.join(continuous_words[i:j])
+                        appears[word] += 1
+                        parts[word] = continuous_words[i:j]
 
         w = []
         for cur in range(0, len(words)):
@@ -149,4 +151,6 @@ class KeywordsExtractor:
 
 def extract_keywords(doc, with_weight=False):
     extractor = KeywordsExtractor()
+    # 繁体转简体
+    doc = traditional_to_simple(doc)
     return extractor.extract_keywords(doc, with_weight=with_weight)
